@@ -78,6 +78,7 @@ class MailNotificationsForm(FlaskForm):
 
 class FiltersNotificationForm(FlaskForm):
     new_cve = BooleanField("New CVE")
+    first_time = BooleanField("Subscription appeared for the first time")
     references = BooleanField("Reference changed")
     cvss = BooleanField("CVSS changed")
     cpes = BooleanField("CPE changed")
@@ -110,3 +111,13 @@ class TagForm(FlaskForm):
         default="#000000",
     )
     submit = SubmitField("Save")
+
+
+class ActivitiesViewForm(FlaskForm):
+    view = RadioField(
+        "Activities View",
+        choices=[
+            ("all", "Display all activities"),
+            ("subscriptions", "Display subscriptions activities"),
+        ],
+    )
