@@ -41,6 +41,7 @@ class Config(object):
 
     DISPLAY_WELCOME = config.getboolean("core", "display_welcome", fallback=False)
     DISPLAY_TERMS = config.getboolean("core", "display_terms", fallback=False)
+    INCLUDE_ANALYTICS = config.getboolean("core", "include_analytics", fallback=False)
 
     # Customize the server name
     if config.get("core", "server_name"):
@@ -64,6 +65,9 @@ class Config(object):
         "CELERY_ACCEPT_CONTENT": ["json"],
         "CELERYD_HIJACK_ROOT_LOGGER": False,
     }
+    CELERY_LOCK_URL = config.get(
+        "core", "celery_lock_url", fallback="redis://127.0.0.1:6379/2"
+    )
 
     # Pagination
     CVES_PER_PAGE = config.getint("core", "cves_per_page", fallback=20)
@@ -84,6 +88,9 @@ class Config(object):
     COUNT_EXCERPT = 3
     REPORT_COUNT_EXCERPT = 3
 
+    # Cleanup
+    REPORTS_CLEANUP_DAYS = config.getint("core", "reports_cleanup_days", fallback=0)
+
     # Flask-User
     USER_APP_NAME = "OpenCVE.io"
     USER_ENABLE_CHANGE_USERNAME = False
@@ -125,6 +132,7 @@ class Config(object):
     MAIL_SERVER = config.get("mail", "smtp_server")
     MAIL_PORT = config.getint("mail", "smtp_port", fallback=465)
     MAIL_USE_TLS = config.getboolean("mail", "smtp_use_tls", fallback=True)
+    MAIL_USE_SSL = config.getboolean("mail", "smtp_use_ssl", fallback=False)
     MAIL_USERNAME = config.get("mail", "smtp_username")
 
     # ensure compatibility before deprecating "stmp_password"
